@@ -111,10 +111,6 @@ require_internal_units (const char *normal_dir, const char *early_dir, const cha
 
   if (!glnx_shutil_mkdir_p_at (normal_dir_dfd, "multi-user.target.wants", 0755, cancellable, error))
     return FALSE;
-  if (symlinkat (SYSTEM_DATA_UNIT_PATH "/ostree-finalize-staged.path", normal_dir_dfd,
-                 "multi-user.target.wants/ostree-finalize-staged.path")
-      < 0)
-    return glnx_throw_errno_prefix (error, "symlinkat");
   if (symlinkat (SYSTEM_DATA_UNIT_PATH "/ostree-boot-complete.service", normal_dir_dfd,
                  "multi-user.target.wants/ostree-boot-complete.service")
       < 0)
