@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  *
  * Author: Colin Walters <walters@verbum.org>
  */
@@ -24,14 +22,31 @@
 #pragma once
 
 #include <gio/gio.h>
-#include <string.h> /* Yeah...let's just do that here. */
 #include <libglnx.h>
+#include <string.h> /* Yeah...let's just do that here. */
+#include <syslog.h>
+
+#ifdef HAVE_LIBSYSTEMD
+#include <systemd/sd-journal.h>
+#endif
 
 /* https://bugzilla.gnome.org/show_bug.cgi?id=766370 */
 #if !GLIB_CHECK_VERSION(2, 49, 3)
-#define OT_VARIANT_BUILDER_INITIALIZER {{0,}}
+#define OT_VARIANT_BUILDER_INITIALIZER \
+  { \
+    { \
+      0, \
+    } \
+  }
 #else
-#define OT_VARIANT_BUILDER_INITIALIZER {{{0,}}}
+#define OT_VARIANT_BUILDER_INITIALIZER \
+  { \
+    { \
+      { \
+        0, \
+      } \
+    } \
+  }
 #endif
 
 static inline const char *
@@ -42,20 +57,27 @@ ot_booltostr (int b)
 
 #define ot_gobject_refz(o) (o ? g_object_ref (o) : o)
 
-#define ot_transfer_out_value(outp, srcp) G_STMT_START {   \
-  if (outp)                                                \
-    {                                                      \
-      *outp = *srcp;                                       \
-      *(srcp) = NULL;                                      \
-    }                                                      \
-  } G_STMT_END;
+#define ot_transfer_out_value(outp, srcp) \
+  G_STMT_START \
+  { \
+    if (outp) \
+      { \
+        *outp = *srcp; \
+        *(srcp) = NULL; \
+      } \
+  } \
+  G_STMT_END;
 
 #ifdef HAVE_LIBSYSTEMD
-#define ot_journal_send(...) sd_journal_send(__VA_ARGS__)
-#define ot_journal_print(...) sd_journal_print(__VA_ARGS__)
+#define ot_journal_send(...) sd_journal_send (__VA_ARGS__)
+#define ot_journal_print(...) sd_journal_print (__VA_ARGS__)
 #else
-#define ot_journal_send(...) {}
-#define ot_journal_print(...) {}
+#define ot_journal_send(...) \
+  { \
+  }
+#define ot_journal_print(...) \
+  { \
+  }
 #endif
 
 typedef GMainContext GMainContextPopDefault;
@@ -82,17 +104,16 @@ _ostree_main_context_new_default (void)
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GMainContextPopDefault, _ostree_main_context_pop_default_destroy)
 
-
-#include <ot-keyfile-utils.h>
-#include <ot-gio-utils.h>
-#include <ot-fs-utils.h>
-#include <ot-opt-utils.h>
-#include <ot-unix-utils.h>
-#include <ot-variant-utils.h>
-#include <ot-variant-builder.h>
-#include <ot-checksum-utils.h>
 #include <ot-checksum-instream.h>
+#include <ot-checksum-utils.h>
+#include <ot-fs-utils.h>
+#include <ot-gio-utils.h>
+#include <ot-keyfile-utils.h>
+#include <ot-opt-utils.h>
 #include <ot-tool-util.h>
+#include <ot-unix-utils.h>
+#include <ot-variant-builder.h>
+#include <ot-variant-utils.h>
 
 #ifndef OSTREE_DISABLE_GPGME
 #include <ot-gpg-utils.h>
