@@ -25,7 +25,7 @@ set -euo pipefail
 unset OSTREE_SKIP_CACHE
 
 COMMIT_SIGN=""
-if has_gpgme; then
+if has_ostree_feature gpgme; then
     COMMIT_SIGN="--gpg-homedir=${TEST_GPG_KEYHOME} --gpg-sign=${TEST_GPG_KEYID_1}"
     echo "1..10"
 else
@@ -63,7 +63,7 @@ assert_file_has_content yet-another-copy/yet-another-hello-world "hello world ye
 ${CMD_PREFIX} ostree --repo=repo fsck
 echo "ok pull mirror summary"
 
-if ! has_gpgme; then
+if ! has_ostree_feature gpgme; then
     exit 0;
 fi
 
